# Command-line interface

The executable (a.k.a. binary or program) is `ocdscardinal`.

[ZIP archives of precompiled binaries for OCDS Cardinal are available for Windows, macOS and Linux.](https://github.com/open-contracting/cardinal-rs/releases)

If you're a **Rust programmer**, ocdscardinal can be installed with `cargo`:

```bash
cargo install ocdscardinal
```

:::{toctree}
:caption: Commands
:maxdepth: 1

init
coverage
prepare
indicators/index
:::
